pub struct VibePattern<'a>(/* private fields */);Implementations
Sourceimpl<'a> VibePattern<'a>
impl<'a> VibePattern<'a>
Sourcepub fn new(durations: &'a [u32]) -> Result<Self, VibePatternError>
pub fn new(durations: &'a [u32]) -> Result<Self, VibePatternError>
Errors
If durations is empty, contains an element larger than 10_000ms or
its length doesn’t fit 32 bit (but good luck allocating that on a Pebble 😉).
pub fn as_sys(&self) -> sysVibePattern<'a>