Struct Window

pub struct Window<T: ?Sized>(/* private fields */);

Implementations

Source

impl<T> Window<T>

pub fn new<'a, L: 'a + FnMut() -> T, A: 'a + FnMut(&mut T), D: 'a + FnMut(&mut T), U: 'a + FnMut(T)>( window_handlers: WindowHandlers<L, A, D, U, T>, ) -> Result<Self, WindowCreationError<L, A, D, U, T>>
where T: 'a,

Creates a new Window<T> instance with the specified window handlers.

Errors

This function errors if associated data can’t be allocated on the heap or if the window can’t be created for another reason.

pub unsafe fn from_raw(raw_window: &'static mut sysWindow) -> Self

Assembles a new instance of Window<T> from the given raw window handle.

Safety

This function is only safe if raw_window is a raw window handle that was previously .leak()ed from the same Window<T> variant and no other Window<T> instance has been created from it since.

pub fn leak(self) -> &'static mut sysWindow
where T: 'static,

Leaks the current Window<T> instance into a raw Pebble window handle.

Note that Window<T> has associated heap instances beyond the raw window, so only destroying that would still leak memory.

Source

impl<T: ?Sized> Window<T>

pub fn hide(&self, animated: bool) -> bool

pub fn is_loaded(&self) -> bool

pub fn show(&self, animated: bool)

Pushes this window onto the window navidation stack, as topmost window of the app.

Arguments

animated: Whether to animate the push using a sliding animation.

pub fn set_background_color(&self, background_color: Color8)