Struct WindowRef

pub struct WindowRef<'a>(/* private fields */);

Methods from Deref<Target = Window<void>>

pub fn hide(&self, animated: bool) -> bool

pub fn is_loaded(&self) -> bool

pub fn show(&self, animated: bool)

Pushes this window onto the window navidation stack, as topmost window of the app.

Arguments

animated: Whether to animate the push using a sliding animation.

pub fn set_background_color(&self, background_color: Color8)