pub struct Window<T: ?Sized>(/* private fields */);Implementations
Sourceimpl<T> Window<T>
impl<T> Window<T>
Sourcepub fn new<'a, L: 'a + FnMut() -> T, A: 'a + FnMut(&mut T), D: 'a + FnMut(&mut T), U: 'a + FnMut(T)>(
window_handlers: WindowHandlers<L, A, D, U, T>,
) -> Result<Self, WindowCreationError<L, A, D, U, T>>where
T: 'a,
pub fn new<'a, L: 'a + FnMut() -> T, A: 'a + FnMut(&mut T), D: 'a + FnMut(&mut T), U: 'a + FnMut(T)>(
window_handlers: WindowHandlers<L, A, D, U, T>,
) -> Result<Self, WindowCreationError<L, A, D, U, T>>where
T: 'a,
Creates a new Window<T> instance with the specified window handlers.
Errors
This function errors if associated data can’t be allocated on the heap or if the window can’t be created for another reason.
Sourceimpl<T: ?Sized> Window<T>
impl<T: ?Sized> Window<T>
pub fn hide(&self, animated: bool) -> bool
pub fn is_loaded(&self) -> bool
Sourcepub fn show(&self, animated: bool)
pub fn show(&self, animated: bool)
Pushes this window onto the window navidation stack, as topmost window of the app.
Arguments
animated: Whether to animate the push using a sliding animation.
pub fn set_background_color(&self, background_color: Color8)